@@ -30,6 +30,10 @@ class DriverElement(DrissionElement):
         attrs = [f"{attr}='{self.attrs[attr]}'" for attr in self.attrs]
         return f'<DriverElement {self.tag} {" ".join(attrs)}>'
 
+    @property
+    def driver(self) -> WebDriver:
+        return self._driver
+
     @property
     def attrs(self) -> dict:
         """返回元素所有属性及值"""
@@ -105,7 +109,11 @@ class DriverElement(DrissionElement):
             # return self.attrs[attr]
             return self.inner_ele.get_attribute(attr)
 
-    def ele(self, loc_or_str: Union[tuple, str], mode: str = None, show_errmsg: bool = False, timeout: float = None):
+    def ele(self,
+            loc_or_str: Union[tuple, str],
+            mode: str = None,
+            show_errmsg: bool = False,
+            timeout: float = None):
         """根据loc获取元素或列表，可用用字符串控制获取方式，可选'id','class','name','tagName'
         例：ele.find('id:ele_id')
         """
@@ -124,7 +132,10 @@ class DriverElement(DrissionElement):
         timeout = timeout or self.timeout
         return execute_driver_find(self.inner_ele, loc_or_str, mode, show_errmsg, timeout)
 
-    def eles(self, loc_or_str: Union[tuple, str], show_errmsg: bool = False, timeout: float = None):
+    def eles(self,
+             loc_or_str: Union[tuple, str],
+             show_errmsg: bool = False,
+             timeout: float = None):
         """根据loc获取子元素列表"""
         return self.ele(loc_or_str, mode='all', show_errmsg=show_errmsg, timeout=timeout)
 
@@ -142,6 +153,7 @@ class DriverElement(DrissionElement):
         if by_js is not False:
             self.run_script('arguments[0].click()')
             return True
+        return False
 
     def input(self, value, clear: bool = True) -> bool:
         """输入文本"""
@@ -228,32 +240,72 @@ class DriverElement(DrissionElement):
         except:
             raise
 
-    def drag_to(self, ele_or_loc: Union[tuple, WebElement, DrissionElement]) -> bool:
+    def drag(self, x: int, y: int, speed: int = 40, shake: bool = True) -> bool:
+        """拖拽当前元素到相对位置
+        :param x: x变化值
+        :param y: y变化值
+        :param speed: 速度
+        :param shake: 是否随机抖动
+        :return: 是否推拽成功
+        """
+        x += self.location['x'] + self.size['width'] // 2
+        y += self.location['y'] + self.size['height'] // 2
+        return self.drag_to((x, y), speed, shake)
+
+    def drag_to(self,
+                ele_or_loc: Union[tuple, WebElement, DrissionElement],
+                speed: int = 40,
+                shake: bool = True) -> bool:
         """拖拽当前元素，目标为另一个元素或坐标元组
-        :param ele_or_loc: 另一个元素或相对当前位置
+        :param ele_or_loc: 另一个元素或坐标元组，坐标为元素中点的坐标
+        :param speed: 拖动的速度，默认为None即瞬间到达
+        :param shake: 是否随机抖动
         :return: 是否拖拽成功
         """
-        from selenium.webdriver import ActionChains
-        loc1 = self.location
-        actions = ActionChains(self._driver)
-
-        if isinstance(ele_or_loc, DriverElement):
-            actions.drag_and_drop(self.inner_ele, ele_or_loc.inner_ele)
-        elif isinstance(ele_or_loc, WebElement):
-            actions.drag_and_drop(self.inner_ele, ele_or_loc)
+        # x, y：目标坐标点
+        if isinstance(ele_or_loc, DriverElement) or isinstance(ele_or_loc, WebElement):
+            target_x = ele_or_loc.location['x'] + ele_or_loc.size['width'] // 2
+            target_y = ele_or_loc.location['y'] + ele_or_loc.size['height'] // 2
         elif isinstance(ele_or_loc, tuple):
-            actions.drag_and_drop_by_offset(self.inner_ele, ele_or_loc[0], ele_or_loc[1])
+            target_x, target_y = ele_or_loc
         else:
-            raise KeyError('Need WebElement object or coordinate information.')
-        actions.perform()
-        loc2 = self.location
-        if loc1 == loc2:
-            return False
-        return True
+            raise KeyError('Need DriverElement, WebElement object or coordinate information.')
+
+        current_x = self.location['x'] + self.size['width'] // 2
+        current_y = self.location['y'] + self.size['height'] // 2
+        width = target_x - current_x
+        height = target_y - current_y
+        num = 0 if not speed else int(((abs(width) ** 2 + abs(height) ** 2) ** .5) // speed)
+        # 将要经过的点存入列表
+        points = [(int(current_x + i * (width / num)), int(current_y + i * (height / num))) for i in range(1, num)]
+        points.append((target_x, target_y))
+
+        from selenium.webdriver import ActionChains
+        from random import randint
+        actions = ActionChains(self.driver)
+        actions.click_and_hold(self.inner_ele)
+        loc1 = self.location
+        for x, y in points:  # 逐个访问要经过的点
+            if shake:
+                x += randint(-3, 4)
+                y += randint(-3, 4)
+            actions.move_by_offset(x - current_x, y - current_y)
+            current_x, current_y = x, y
+        actions.release().perform()
+
+        return False if self.location == loc1 else True
+
+    def hover(self):
+        """鼠标悬停"""
+        from selenium.webdriver import ActionChains
+        ActionChains(self._driver).move_to_element(self.inner_ele).perform()
 
 
-def execute_driver_find(page_or_ele: Union[WebElement, WebDriver], loc: tuple, mode: str = 'single',
-                        show_errmsg: bool = False, timeout: float = 10) -> Union[DriverElement, List[DriverElement]]:
+def execute_driver_find(page_or_ele: Union[WebElement, WebDriver],
+                        loc: tuple,
+                        mode: str = 'single',
+                        show_errmsg: bool = False,
+                        timeout: float = 10) -> Union[DriverElement, List[DriverElement]]:
     """执行driver模式元素的查找
     页面查找元素及元素查找下级元素皆使用此方法
     :param page_or_ele: driver模式页面或元素
